@@ -567,6 +567,8 @@ class Obs:
     ----------
     pos : (3,) float np.ndarray
         ECEF position coordinates from the RINEX file.
+    tz_approx : int
+        Approximate time zone offset based only on the longitude.
     ts_bow : datetime.datetime
         Date and timestamp of the beginning of the week based on the earliest
         observation in the file.
@@ -981,6 +983,7 @@ class Obs:
 
         # Load remaining properties of object.
         self.pos = pos.copy()
+        self.tz_approx = round(np.arctan2(pos[1], pos[0])*12/np.pi)
         self.ts_bow = ts_bow
         self.types = types_list.copy()
         self.len = len(t)
